@@ -3,7 +3,7 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; under version 2 of the License.
+ *  the Free Software Foundation; under version 3 of the License.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -11,12 +11,14 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses>.
+ *
+ *  The Audacious team does not consider modular code linking to
+ *  Audacious or using our public API to be a derived work.
  */
 
-#ifndef ACTIONS_EQUALIZER_H
-#define ACTIONS_EQUALIZER_H
+#ifndef AUDACIOUS_ACTIONS_EQUALIZER_H
+#define AUDACIOUS_ACTIONS_EQUALIZER_H
 
 void action_equ_load_preset(void);
 void action_equ_load_auto_preset(void);
@@ -33,4 +35,4 @@ void action_equ_save_preset_eqf(void);
 void action_equ_delete_preset(void);
 void action_equ_delete_auto_preset(void);
 
-#endif
+#endif /* AUDACIOUS_ACTIONS_EQUALIZER_H */
