@@ -20,11 +20,12 @@
  *  Audacious or using our public API to be a derived work.
  */
 
-#ifndef LOGGER_H
-#define LOGGER_H
+#ifndef AUDACIOUS_LOGGER_H
+#define AUDACIOUS_LOGGER_H
 
 #include <glib.h>
 
+G_BEGIN_DECLS
 
 #define BMP_LOGGER_DEFAULT_LOG_LEVEL  G_LOG_LEVEL_MESSAGE
 
@@ -32,7 +33,9 @@
 #define BMP_LOGGER_FILE_MAX_SIZE      ((size_t)1 << 19)
 
 
-gboolean bmp_logger_start(const gchar * filename);
-void bmp_logger_stop(void);
+gboolean aud_logger_start(const gchar * filename);
+void aud_logger_stop(void);
 
-#endif
+G_END_DECLS
+
+#endif /* AUDACIOUS_LOGGER_H */
