@@ -32,8 +32,8 @@
  * SUCH DAMAGE.
  */
 
-#ifndef BMP_PLUGIN_H
-#define BMP_PLUGIN_H
+#ifndef AUDACIOUS_PLUGIN_H
+#define AUDACIOUS_PLUGIN_H
 
 #include <glib.h>
 #include <gtk/gtk.h>
@@ -86,7 +86,7 @@ typedef enum {
     FMT_S32_NE,
 
     FMT_FLOAT,
-    FMT_FIXED32, /* equivalent of libmad's mad_fixed_t explained below */
+    FMT_FIXED32 /* equivalent of libmad's mad_fixed_t explained below */
 } AFormat;
 
 /* From mad.h:
@@ -157,8 +157,6 @@ typedef GHashTable INIFile;
 #include "audacious/mime.h"
 #include "audacious/custom_uri.h"
 #include "audacious/hook.h"
-#include "audacious/ui_plugin_menu.h"
-#include "audacious/formatter.h"
 #include "audacious/flow.h"
 
 #define PLUGIN_COMMON_FIELDS		\
@@ -252,52 +250,52 @@ struct _AudaciousFuncTableV1 {
     VFSFile *(*vfs_buffered_file_release_live_fd)(VFSFile *fd);
 
     /* ConfigDb */
-    ConfigDb *(*cfg_db_open)(void);
-    void (*cfg_db_close)(ConfigDb *db);
+    mcs_handle_t *(*cfg_db_open)(void);
+    void (*cfg_db_close)(mcs_handle_t *db);
 
-    gboolean (*cfg_db_get_string)(ConfigDb *db,
+    gboolean (*cfg_db_get_string)(mcs_handle_t *db,
                                   const gchar *section,
                                   const gchar *key,
                                   gchar **value);
-    gboolean (*cfg_db_get_int)(ConfigDb *db,
+    gboolean (*cfg_db_get_int)(mcs_handle_t *db,
                                const gchar *section,
                                const gchar *key,
                                gint *value);
-    gboolean (*cfg_db_get_bool)(ConfigDb *db,
+    gboolean (*cfg_db_get_bool)(mcs_handle_t *db,
                                 const gchar *section,
                                 const gchar *key,
                                 gboolean *value);
-    gboolean (*cfg_db_get_float)(ConfigDb *db,
+    gboolean (*cfg_db_get_float)(mcs_handle_t *db,
                                  const gchar *section,
                                  const gchar *key,
                                  gfloat *value);
-    gboolean (*cfg_db_get_double)(ConfigDb *db,
+    gboolean (*cfg_db_get_double)(mcs_handle_t *db,
                                   const gchar *section,
                                   const gchar *key,
                                   gdouble *value);
 
-    void (*cfg_db_set_string)(ConfigDb *db,
+    void (*cfg_db_set_string)(mcs_handle_t *db,
                               const gchar *section,
                               const gchar *key,
                               const gchar *value);
-    void (*cfg_db_set_int)(ConfigDb *db,
+    void (*cfg_db_set_int)(mcs_handle_t *db,
                            const gchar *section,
                            const gchar *key,
                            gint value);
-    void (*cfg_db_set_bool)(ConfigDb *db,
+    void (*cfg_db_set_bool)(mcs_handle_t *db,
                             const gchar *section,
                             const gchar *key,
                             gboolean value);
-    void (*cfg_db_set_float)(ConfigDb *db,
+    void (*cfg_db_set_float)(mcs_handle_t *db,
                              const gchar *section,
                              const gchar *key,
                              gfloat value);
-    void (*cfg_db_set_double)(ConfigDb *db,
+    void (*cfg_db_set_double)(mcs_handle_t *db,
                               const gchar *section,
                               const gchar *key,
                               gdouble value);
 
-    void (*cfg_db_unset_key)(ConfigDb *db,
+    void (*cfg_db_unset_key)(mcs_handle_t *db,
                              const gchar *section,
                              const gchar *key);
 
@@ -515,7 +513,7 @@ struct _AudaciousFuncTableV1 {
 
     /* state vars */
     InputPluginData *ip_state;
-    BmpConfig *_cfg;
+    AudConfig *_cfg;
 
     /* hook API */
     void (*hook_register)(const gchar *name);
@@ -594,14 +592,6 @@ struct _AudaciousFuncTableV1 {
     gint (*drct_pq_get_position)( gint pos );
     gint (*drct_pq_get_queue_position)( gint pos );
 
-    /* Formatter API */
-    Formatter *(*formatter_new)(void);
-    void (*formatter_destroy)(Formatter * formatter);
-    void (*formatter_associate)(Formatter * formatter, guchar id,
-                                gchar * value);
-    void (*formatter_dissociate)(Formatter * formatter, guchar id);
-    gchar *(*formatter_format)(Formatter * formatter, gchar * format);
-
     gint (*prefswin_page_new)(GtkWidget *container, gchar *name, gchar *imgurl);
     void (*prefswin_page_destroy)(GtkWidget *container);
 
@@ -653,6 +643,13 @@ struct _AudaciousFuncTableV1 {
 
     void (*event_queue)(const gchar *name, gpointer user_data);
 
+    /* VFS endianess helper functions */
+    gboolean (*vfs_fget_le16)(guint16 *value, VFSFile *stream);
+    gboolean (*vfs_fget_le32)(guint32 *value, VFSFile *stream);
+    gboolean (*vfs_fget_le64)(guint64 *value, VFSFile *stream);
+    gboolean (*vfs_fget_be16)(guint16 *value, VFSFile *stream);
+    gboolean (*vfs_fget_be32)(guint32 *value, VFSFile *stream);
+    gboolean (*vfs_fget_be64)(guint64 *value, VFSFile *stream);
 };
 
 /* Convenience macros for accessing the public API. */
@@ -686,20 +683,28 @@ struct _AudaciousFuncTableV1 {
 #define aud_vfs_buffered_file_new_from_uri	_audvt->vfs_buffered_file_new_from_uri
 #define aud_vfs_buffered_file_release_live_fd	_audvt->vfs_buffered_file_release_live_fd
 
+#define aud_vfs_fget_le16		_audvt->vfs_fget_le16
+#define aud_vfs_fget_le32		_audvt->vfs_fget_le32
+#define aud_vfs_fget_le64		_audvt->vfs_fget_le64
+#define aud_vfs_fget_be16		_audvt->vfs_fget_be16
+#define aud_vfs_fget_be32		_audvt->vfs_fget_be32
+#define aud_vfs_fget_be64		_audvt->vfs_fget_be64
+
 /* XXX: deprecation warnings */
-#define bmp_cfg_db_open			_audvt->cfg_db_open
-#define bmp_cfg_db_close		_audvt->cfg_db_close
-#define bmp_cfg_db_set_string		_audvt->cfg_db_set_string
-#define bmp_cfg_db_set_int		_audvt->cfg_db_set_int
-#define bmp_cfg_db_set_bool		_audvt->cfg_db_set_bool
-#define bmp_cfg_db_set_float		_audvt->cfg_db_set_float
-#define bmp_cfg_db_set_double		_audvt->cfg_db_set_double
-#define bmp_cfg_db_get_string		_audvt->cfg_db_get_string
-#define bmp_cfg_db_get_int		_audvt->cfg_db_get_int
-#define bmp_cfg_db_get_bool		_audvt->cfg_db_get_bool
-#define bmp_cfg_db_get_float		_audvt->cfg_db_get_float
-#define bmp_cfg_db_get_double		_audvt->cfg_db_get_double
-#define bmp_cfg_db_unset_key		_audvt->cfg_db_unset_key
+#define ConfigDb mcs_handle_t		/* Alias for compatibility -- ccr */
+#define aud_cfg_db_open			_audvt->cfg_db_open
+#define aud_cfg_db_close		_audvt->cfg_db_close
+#define aud_cfg_db_set_string		_audvt->cfg_db_set_string
+#define aud_cfg_db_set_int		_audvt->cfg_db_set_int
+#define aud_cfg_db_set_bool		_audvt->cfg_db_set_bool
+#define aud_cfg_db_set_float		_audvt->cfg_db_set_float
+#define aud_cfg_db_set_double		_audvt->cfg_db_set_double
+#define aud_cfg_db_get_string		_audvt->cfg_db_get_string
+#define aud_cfg_db_get_int		_audvt->cfg_db_get_int
+#define aud_cfg_db_get_bool		_audvt->cfg_db_get_bool
+#define aud_cfg_db_get_float		_audvt->cfg_db_get_float
+#define aud_cfg_db_get_double		_audvt->cfg_db_get_double
+#define aud_cfg_db_unset_key		_audvt->cfg_db_unset_key
 
 #define aud_cfg_db_open			_audvt->cfg_db_open
 #define aud_cfg_db_close		_audvt->cfg_db_close
@@ -941,12 +946,6 @@ struct _AudaciousFuncTableV1 {
 #define audacious_drct_pq_get_position		_audvt->drct_pq_get_position
 #define audacious_drct_pq_get_queue_position	_audvt->drct_pq_get_queue_position
 
-#define aud_formatter_new			_audvt->formatter_new
-#define aud_formatter_destroy			_audvt->formatter_destroy
-#define aud_formatter_associate			_audvt->formatter_associate
-#define aud_formatter_dissociate		_audvt->formatter_dissociate
-#define aud_formatter_format			_audvt->formatter_format
-
 #define aud_prefswin_page_new			_audvt->prefswin_page_new
 #define aud_prefswin_page_destroy		_audvt->prefswin_page_destroy
 
@@ -1144,7 +1143,7 @@ struct _InputPlugin {
     /* Added in Audacious 1.1.0 */
     Tuple *(*get_song_tuple) (gchar * filename);
     void (*set_song_tuple) (Tuple * tuple); /* stillborn, obsoleted by update_song_tuple, which must be used for tag writing */
-    void (*set_status_buffering) (gboolean status);
+    void (*set_status_buffering) (gboolean status); /* unfunctional */
 
     /* Added in Audacious 1.3.0 */
     gint (*is_our_file_from_vfs) (gchar *filename, VFSFile *fd);
@@ -1188,6 +1187,13 @@ struct _VisPlugin {
     void (*playback_start) (void);
     void (*playback_stop) (void);
     void (*render_pcm) (gint16 pcm_data[2][512]);
+    
+    /* The range of intensities is 0 - 32767 (though theoretically it is
+     * possible for the FFT to result in bigger values, making the final
+     * intensity negative due to overflowing the 16bit signed integer.)
+     *
+     * If output is mono, only freq_data[0] is filled.
+     */
     void (*render_freq) (gint16 freq_data[2][256]);
 };
 
@@ -1200,4 +1206,4 @@ struct _DiscoveryPlugin {
 /* undefine the macro -- struct Plugin should be used instead. */
 #undef PLUGIN_COMMON_FIELDS
 
-#endif
+#endif /* AUDACIOUS_PLUGIN_H */
