@@ -38,8 +38,6 @@
 #include <string.h>
 
 #include "main.h"
-#include "dock.h"
-#include "ui_main.h"
 #include "playback.h"
 #include "playlist.h"
 #include "strings.h"
@@ -57,11 +55,14 @@
 #include "vfs_buffer.h"
 #include "vfs_buffered_file.h"
 
+#include "ui_dock.h"
 #include "ui_preferences.h"
+#include "ui_fileinfo.h"
 #include "ui_fileinfopopup.h"
 
 #include "effect.h"
 #include "volumecontrol.h"
+#include "ui_plugin_menu.h"
 
 const gchar *plugin_dir_list[] = {
     PLUGINSUBS,
@@ -104,6 +105,13 @@ static struct _AudaciousFuncTableV1 _aud_papi_v1 = {
 
     .vfs_buffered_file_new_from_uri = vfs_buffered_file_new_from_uri,
     .vfs_buffered_file_release_live_fd = vfs_buffered_file_release_live_fd,
+    
+    .vfs_fget_le16 = vfs_fget_le16,
+    .vfs_fget_le32 = vfs_fget_le32,
+    .vfs_fget_le64 = vfs_fget_le64,
+    .vfs_fget_be16 = vfs_fget_be16,
+    .vfs_fget_be32 = vfs_fget_be32,
+    .vfs_fget_be64 = vfs_fget_be64,
 
     .cfg_db_open = cfg_db_open,
     .cfg_db_close = cfg_db_close,
@@ -223,11 +231,11 @@ static struct _AudaciousFuncTableV1 _aud_papi_v1 = {
     .playlist_remove_duplicates = playlist_remove_duplicates,
     .playlist_remove_dead_files = playlist_remove_dead_files,
 
-    .playlist_fileinfo_current = playlist_fileinfo_current,
-    .playlist_fileinfo = playlist_fileinfo,
+    .playlist_fileinfo_current = ui_fileinfo_show_current,
+    .playlist_fileinfo = ui_fileinfo_show,
 
     .playlist_delete_index = playlist_delete_index,
-    .playlist_delete_filenames = playlist_delete_filenames,
+    .playlist_delete_filenames = NULL, /* remove eventually --mf0102 */
 
     .playlist_get_entry_to_play = playlist_get_entry_to_play,
 
@@ -298,7 +306,7 @@ static struct _AudaciousFuncTableV1 _aud_papi_v1 = {
     .drct_eq_win_toggle = drct_eq_win_toggle,
     .drct_pl_win_is_visible = drct_pl_win_is_visible,
     .drct_pl_win_toggle = drct_pl_win_toggle,
-    .drct_set_skin = drct_set_skin,
+    .drct_set_skin = NULL, /* remove someday. --mf0102 */
     .drct_activate = drct_activate,
 
     .drct_play = drct_play,
@@ -344,12 +352,6 @@ static struct _AudaciousFuncTableV1 _aud_papi_v1 = {
     .drct_pq_get_position = drct_pq_get_position,
     .drct_pq_get_queue_position = drct_pq_get_queue_position,
 
-    .formatter_new = formatter_new,
-    .formatter_destroy = formatter_destroy,
-    .formatter_associate = formatter_associate,
-    .formatter_dissociate = formatter_dissociate,
-    .formatter_format = formatter_format,
-
     .prefswin_page_new = prefswin_page_new,
     .prefswin_page_destroy = prefswin_page_destroy,
 
@@ -399,7 +401,7 @@ static struct _AudaciousFuncTableV1 _aud_papi_v1 = {
 GList *lowlevel_list = NULL;
 extern GList *vfs_transports;
 
-mowgli_dictionary_t *plugin_dict = NULL;
+static mowgli_dictionary_t *plugin_dict = NULL;
 
 static GStaticPrivate cur_plugin_key = G_STATIC_PRIVATE_INIT;
 static mowgli_dictionary_t *pvt_data_dict = NULL;
@@ -551,7 +553,7 @@ input_plugin_init(Plugin * plugin)
        - descender */
     p->set_info = (void (*)(gchar *, gint, gint, gint, gint)) playlist_set_info_old_abi;
     p->set_info_text = input_set_info_text;
-    p->set_status_buffering = input_set_status_buffering;
+    p->set_status_buffering = NULL; /* XXX: remove this someday --mf0102 */
 
     ip_data.input_list = g_list_append(ip_data.input_list, p);
     
@@ -831,7 +833,7 @@ plugin_system_init(void)
     ext_hash = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
 
 #ifndef DISABLE_USER_PLUGIN_DIR
-    scan_plugins(bmp_paths[BMP_PATH_USER_PLUGIN_DIR]);
+    scan_plugins(aud_paths[BMP_PATH_USER_PLUGIN_DIR]);
     /*
      * This is in a separate lo
      * DiscoveryPlugin *dpop so if the user puts them in the
@@ -839,7 +841,7 @@ plugin_system_init(void)
      * first)                                                - Zinx
      */
     while (plugin_dir_list[dirsel]) {
-        dir = g_build_filename(bmp_paths[BMP_PATH_USER_PLUGIN_DIR],
+        dir = g_build_filename(aud_paths[BMP_PATH_USER_PLUGIN_DIR],
                                plugin_dir_list[dirsel++], NULL);
         scan_plugins(dir);
         g_free(dir);
