@@ -33,10 +33,11 @@
 #endif
 
 #include "main.h"
-#include "ui_main.h"
 #include "signals.h"
 #include "build_stamp.h"
+#ifdef USE_EGGSM
 #include "eggsmclient.h"
+#endif
 
 gint linuxthread_signal_number = 0;
 
@@ -47,7 +48,7 @@ signal_process_segv(void)
          "We apologize for the inconvenience, but Audacious has crashed.\n"
          "This is a bug in the program, and should never happen under normal circumstances.\n"
 	 "Your current configuration has been saved and should not be damaged.\n\n"
-	 "You can help improve the quality of Audacious by filing a bug at http://bugs-meta.atheme.org\n"
+	 "You can help improve the quality of Audacious by filing a bug at http://bugzilla.atheme.org/\n"
          "Please include the entire text of this message and a description of what you were doing when\n"
          "this crash occured in order to quickly expedite the handling of your bug report:\n\n"));
 
@@ -71,14 +72,16 @@ signal_process_segv(void)
         g_free(strings);
     }
 #else
-    g_printerr("Stacktrace was unavailable.\n");
+    g_printerr(_("Stacktrace was unavailable. You might want to reproduce this "
+    "problem while running Audacious under GDB to get a proper backtrace.\n"));
 #endif
 
-    g_printerr(_("\nBugs can be reported at http://bugs-meta.atheme.org against the Audacious product.\n"));
+    g_printerr(_("\nBugs can be reported at http://bugzilla.atheme.org/ against "
+    "the Audacious or Audacious Plugins product.\n"));
 
     g_critical("Received SIGSEGV -- Audacious has crashed.");
 
-    bmp_config_save();
+    aud_config_save();
     abort();
 }
 
@@ -110,12 +113,12 @@ signal_process_signals (void *data)
 
         case SIGINT:
             g_print("Audacious has received SIGINT and is shutting down.\n");
-            mainwin_quit_cb();
+            aud_quit();
             break;
 
         case SIGTERM:
             g_print("Audacious has received SIGTERM and is shutting down.\n");
-            mainwin_quit_cb();
+            aud_quit();
             break;
         }
     }
@@ -149,12 +152,12 @@ signal_process_signals_linuxthread (void *data)
 
         case SIGINT:
             g_print("Audacious has received SIGINT and is shutting down.\n");
-            mainwin_quit_cb();
+            aud_quit();
             break;
 
         case SIGTERM:
             g_print("Audacious has received SIGTERM and is shutting down.\n");
-            mainwin_quit_cb();
+            aud_quit();
             break;
         }
     }
@@ -250,23 +253,26 @@ signal_check_for_broken_impl(void)
     return FALSE;
 }
 
+#ifdef USE_EGGSM
 static void
 signal_session_quit_cb(EggSMClient *client, gpointer user_data)
 {
     g_print("Session quit requested. Saving state and shutting down.\n");    
-    mainwin_quit_cb();
+    aud_quit();
 }
 
 static void
 signal_session_save_cb(EggSMClient *client, const char *state_dir, gpointer user_data)
 {
     g_print("Session save requested. Saving state.\n");    
-    bmp_config_save();
+    aud_config_save();
 }
+#endif
 
 void 
 signal_handlers_init(void)
 {
+#ifdef USE_EGGSM
     EggSMClient *client;
 
     client = egg_sm_client_get ();
@@ -279,6 +285,7 @@ signal_handlers_init(void)
                           G_CALLBACK (signal_session_save_cb), NULL);
     
     }
+#endif
 
     if (signal_check_for_broken_impl() != TRUE)
     {
