@@ -829,3 +829,105 @@ gchar *tuple_formatter_eval(TupleEvalContext *ctx, TupleEvalNode *expr, Tuple *t
   
   return res;
 }
+
+
+static void print_vars(FILE *f, TupleEvalContext *ctx, TupleEvalNode *node, gint start, gint end)
+{
+  gint i;
+
+  for (i = start; i <= end; i++) {
+    TupleEvalVar *v = NULL;
+    gchar *s = NULL;
+    gint n = node->var[i];
+
+    if (n >= 0) {
+      v = ctx->variables[n];
+      if (v) {
+        s = v->name;
+
+        if (v->type == VAR_CONST)
+          fprintf(f, "(const)");
+        else if (v->type == VAR_DEF)
+          fprintf(f, "(def)");
+      }
+    }
+
+    fprintf(f, "var[%d]=(%d),\"%s\" ", i, n, s);
+  }
+}
+
+
+gint tuple_formatter_print(FILE *f, gint *level, TupleEvalContext *ctx, TupleEvalNode *expr)
+{
+  TupleEvalNode *curr = expr;
+
+  if (!expr) return -1;
+
+  (*level)++;
+
+  while (curr) {
+    gint i;
+    for (i = 0; i < *level; i++)
+      fprintf(f, "  ");
+
+    switch (curr->opcode) {
+      case OP_RAW:
+        fprintf(f, "OP_RAW text=\"%s\"\n", curr->text);
+        break;
+
+      case OP_FIELD:
+        fprintf(f, "OP_FIELD ");
+        print_vars(f, ctx, curr, 0, 0);
+        fprintf(f, "\n");
+        break;
+
+      case OP_EXISTS:
+        fprintf(f, "OP_EXISTS ");
+        print_vars(f, ctx, curr, 0, 0);
+        fprintf(f, "\n");
+        tuple_formatter_print(f, level, ctx, curr->children);
+        break;
+
+      case OP_DEF_STRING:
+        fprintf(f, "OP_DEF_STRING ");
+        fprintf(f, "\n");
+        break;
+
+      case OP_DEF_INT:
+        fprintf(f, "OP_DEF_INT ");
+        fprintf(f, "\n");
+        break;
+
+      case OP_EQUALS:
+        fprintf(f, "OP_EQUALS ");
+        print_vars(f, ctx, curr, 0, 1);
+        fprintf(f, "\n");
+        tuple_formatter_print(f, level, ctx, curr->children);
+        break;
+
+      case OP_NOT_EQUALS:
+        fprintf(f, "OP_NOT_EQUALS ");
+        print_vars(f, ctx, curr, 0, 1);
+        fprintf(f, "\n");
+        tuple_formatter_print(f, level, ctx, curr->children);
+        break;
+
+      case OP_IS_EMPTY:
+        fprintf(f, "OP_IS_EMPTY ");
+        print_vars(f, ctx, curr, 0, 0);
+        fprintf(f, "\n");
+        tuple_formatter_print(f, level, ctx, curr->children);
+        break;
+
+      default:
+        fprintf(f, "Unimplemented opcode %d!\n", curr->opcode);
+        break;
+    }
+
+    curr = curr->next;
+  }
+
+  (*level)--;
+
+  return 0;
+}
