@@ -9,7 +9,7 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; under version 2 of the License.
+ *  the Free Software Foundation; under version 3 of the License.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,8 +17,10 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses>.
+ *
+ *  The Audacious team does not consider modular code linking to
+ *  Audacious or using our public API to be a derived work.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -39,8 +41,6 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <X11/Xlib.h>
-
 #include <sys/types.h>
 
 #if defined(USE_REGEX_ONIGURUMA)
@@ -51,7 +51,6 @@
   #include <regex.h>
 #endif
 
-#include "widgets/widgetcore.h"
 #include "ui_main.h"
 #include "icons-stock.h"
 
@@ -59,18 +58,13 @@
 
 #include "main.h"
 
-#include "controlsocket.h"
 #include "dnd.h"
-#include "dock.h"
-#include "genevent.h"
-#include "hints.h"
 #include "input.h"
-#include "libaudacious/configdb.h"
-#include "urldecode.h"
 #include "playback.h"
 #include "playlist.h"
 #include "pluginenum.h"
 #include "ui_credits.h"
+#include "ui_dock.h"
 #include "ui_equalizer.h"
 #include "ui_fileopener.h"
 #include "ui_manager.h"
@@ -84,7 +78,12 @@
 
 #include "ui_skinned_window.h"
 
+#include "ui_jumptotrack_cache.h"
+
 static GtkWidget *jump_to_track_win = NULL;
+static gulong serial = 0;
+
+static JumpToTrackCache* cache = NULL;
 
 static void
 change_song(guint pos)
@@ -96,6 +95,13 @@ change_song(guint pos)
     playback_initiate();
 }
 
+void
+ui_jump_to_track_hide(void)
+{
+    g_return_if_fail(jump_to_track_win != NULL);
+    gtk_widget_hide(jump_to_track_win);
+}
+
 static void
 ui_jump_to_track_jump(GtkTreeView * treeview)
 {
@@ -114,9 +120,22 @@ ui_jump_to_track_jump(GtkTreeView * treeview)
 
     change_song(pos - 1);
 
-    /* FIXME: should only hide window */
-    gtk_widget_destroy(jump_to_track_win);
-    jump_to_track_win = NULL;
+    if(cfg.close_jtf_dialog)
+        ui_jump_to_track_hide();
+}
+
+static void
+ui_jump_to_track_toggle_cb(GtkWidget * toggle)
+{
+    cfg.close_jtf_dialog =
+        gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(toggle));
+}
+
+static void
+ui_jump_to_track_toggle2_cb(GtkWidget * toggle)
+{
+    cfg.remember_jtf_entry =
+        gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(toggle));
 }
 
 static void
@@ -208,9 +227,7 @@ ui_jump_to_track_keypress_cb(GtkWidget * object,
 {
     switch (event->keyval) {
     case GDK_Escape:
-        /* FIXME: show only hide window */
-        gtk_widget_destroy(jump_to_track_win);
-        jump_to_track_win = NULL;
+        ui_jump_to_track_hide();
         return TRUE;
     case GDK_KP_Enter:
         ui_jump_to_track_queue_cb(NULL, data);
@@ -222,33 +239,9 @@ ui_jump_to_track_keypress_cb(GtkWidget * object,
     return FALSE;
 }
 
-static gboolean
-ui_jump_to_track_match(const gchar * song, GSList *regex_list)
-{
-    gboolean rv = TRUE;
-
-    if ( song == NULL )
-        return FALSE;
-
-    for ( ; regex_list ; regex_list = g_slist_next(regex_list) )
-    {
-        regex_t *regex = regex_list->data;
-        if ( regexec( regex , song , 0 , NULL , 0 ) != 0 )
-        {
-            rv = FALSE;
-            break;
-        }
-    }
-
-    return rv;
-}
-
-/* FIXME: Clear the entry when the list gets updated */
 void
 ui_jump_to_track_update(GtkWidget * widget, gpointer user_data)
 {
-    /* FIXME: Is not in sync with playlist due to delayed extinfo
-     * reading */
     guint row;
     GList *playlist_glist;
     gchar *desc_buf = NULL;
@@ -258,10 +251,18 @@ ui_jump_to_track_update(GtkWidget * widget, gpointer user_data)
 
     GtkTreeModel *store;
 
+    GtkTreeView *tree = GTK_TREE_VIEW(g_object_get_data(user_data, "treeview"));
+    GtkEntry *edit = g_object_get_data(user_data, "edit");
+
     if (!jump_to_track_win)
         return;
 
-    store = gtk_tree_view_get_model(GTK_TREE_VIEW(user_data));
+    /* clear edit widget */
+    if(edit){
+        gtk_entry_set_text(edit, "");
+    }
+
+    store = gtk_tree_view_get_model(tree);
     gtk_list_store_clear(GTK_LIST_STORE(store));
 
     row = 1;
@@ -271,26 +272,30 @@ ui_jump_to_track_update(GtkWidget * widget, gpointer user_data)
         PlaylistEntry *entry = PLAYLIST_ENTRY(playlist_glist->data);
 
         if (entry->title)
-        desc_buf = g_strdup(entry->title);
-        else if (strchr(entry->filename, '/'))
-        desc_buf = str_to_utf8(strrchr(entry->filename, '/') + 1);
-        else
-        desc_buf = str_to_utf8(entry->filename);
+            desc_buf = g_strdup(entry->title);
+        else {
+            gchar *realfn = NULL;
+            realfn = g_filename_from_uri(entry->filename, NULL, NULL);
+            if (strchr(realfn ? realfn : entry->filename, '/'))
+                desc_buf = str_to_utf8(strrchr(realfn ? realfn : entry->filename, '/') + 1);
+            else
+                desc_buf = str_to_utf8(realfn ? realfn : entry->filename);
+            g_free(realfn); realfn = NULL;
+        }
 
         gtk_list_store_append(GTK_LIST_STORE(store), &iter);
         gtk_list_store_set(GTK_LIST_STORE(store), &iter,
                            0, row, 1, desc_buf, -1);
         row++;
 
-        if(desc_buf) {
-            g_free(desc_buf);
-            desc_buf = NULL;
-        }
+        g_free(desc_buf);
+        desc_buf = NULL;
     }
 
     gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter);
-    selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(user_data));
+    selection = gtk_tree_view_get_selection(tree);
     gtk_tree_selection_select_iter(selection, &iter);
+    serial = playlist->serial; // important. --yaz
 }
 
 static void
@@ -302,29 +307,12 @@ ui_jump_to_track_edit_cb(GtkEntry * entry, gpointer user_data)
 
     GtkListStore *store;
 
-    guint song_index = 0;
-    gchar **words;
-    GList *playlist_glist;
+    const GArray *search_matches;
     Playlist *playlist;
+    int i;
 
-    gboolean match = FALSE;
-
-    GSList *regex_list = NULL, *regex_list_tmp = NULL;
-    gint i = -1;
-
-    /* Chop the key string into ' '-separated key regex-pattern strings */
-    words = g_strsplit(gtk_entry_get_text(entry), " ", 0);
-
-    /* create a list of regex using the regex-pattern strings */
-    while ( words[++i] != NULL )
-    {
-        regex_t *regex = g_malloc(sizeof(regex_t));
-    #if defined(USE_REGEX_PCRE)
-        if ( regcomp( regex , words[i] , REG_NOSUB | REG_ICASE | REG_UTF8 ) == 0 )
-    #else
-        if ( regcomp( regex , words[i] , REG_NOSUB | REG_ICASE ) == 0 )
-    #endif
-            regex_list = g_slist_append( regex_list , regex );
+    if (cache == NULL) {
+        cache = ui_jump_to_track_cache_new();
     }
 
     /* FIXME: Remove the connected signals before clearing
@@ -338,76 +326,40 @@ ui_jump_to_track_edit_cb(GtkEntry * entry, gpointer user_data)
 
     playlist = playlist_get_active();
 
-    PLAYLIST_LOCK(playlist->mutex);
+    PLAYLIST_LOCK(playlist);
 
-    for (playlist_glist = playlist->entries; playlist_glist;
-         playlist_glist = g_list_next(playlist_glist))
+    search_matches = ui_jump_to_track_cache_search(cache,
+                                                   playlist,
+                                                   gtk_entry_get_text(entry));
+
+    for (i = 0; i < search_matches->len; i++)
     {
-        PlaylistEntry *entry = PLAYLIST_ENTRY(playlist_glist->data);
-        const gchar *title;
-        gchar *filename = NULL;
+        JumpToTrackEntry *jttentry = g_array_index(search_matches, JumpToTrackEntry*, i);
+        PlaylistEntry* entry = jttentry->entry;
+        gchar *title = NULL;
 
-//        g_main_context_iteration(g_main_context_default(), FALSE);
-
-        title = entry->title;
-        if (!title) {
-        filename = str_to_utf8(entry->filename);
-
-            if (strchr(filename, '/'))
-                title = strrchr(filename, '/') + 1;
+        if (entry->title)
+            title = g_strdup(entry->title);
+        else {
+            gchar *realfn = NULL;
+            realfn = g_filename_from_uri(entry->filename, NULL, NULL);
+            if (strchr(realfn ? realfn : entry->filename, '/'))
+                title = str_to_utf8(strrchr(realfn ? realfn : entry->filename, '/') + 1);
             else
-                title = filename;
-        }
-
-        /* Compare the reg.expressions to the string - if all the
-           regexp in regex_list match, add to the ListStore */
-
-        /*
-         * FIXME: The search string should be adapted to the
-         * current display setting, e.g. if the user has set it to
-         * "%p - %t" then build the match string like that too, or
-         * even better, search for each of the tags seperatly.
-         *
-         * In any case the string to match should _never_ contain
-         * something the user can't actually see in the playlist.
-         */
-        if (regex_list != NULL)
-            match = ui_jump_to_track_match(title, regex_list);
-        else
-            match = TRUE;
-
-        if (match) {
-            gtk_list_store_append(store, &iter);
-            gtk_list_store_set(store, &iter, 0, song_index + 1 , 1, title, -1);
-        }
-
-        song_index++;
-
-        if (filename) {
-            g_free(filename);
-            filename = NULL;
+                title = str_to_utf8(realfn ? realfn : entry->filename);
+            g_free(realfn); realfn = NULL;
         }
+        gtk_list_store_append(store, &iter);
+        gtk_list_store_set(store, &iter, 0, jttentry->playlist_position + 1 , 1, title, -1);
+        g_free(title);
     }
 
-    PLAYLIST_UNLOCK(playlist->mutex);
+    PLAYLIST_UNLOCK(playlist);
 
     /* attach the model again to the treeview */
     gtk_tree_view_set_model( GTK_TREE_VIEW(treeview) , GTK_TREE_MODEL(store) );
     g_object_unref( store );
 
-    if ( regex_list != NULL )
-    {
-        regex_list_tmp = regex_list;
-        while ( regex_list != NULL )
-        {
-            regex_t *regex = regex_list->data;
-            regfree( regex );
-            regex_list = g_slist_next(regex_list);
-        }
-        g_slist_free( regex_list_tmp );
-    }
-    g_strfreev(words);
-
     if (gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter)) {
         selection = gtk_tree_view_get_selection(treeview);
         gtk_tree_selection_select_iter(selection, &iter);
@@ -431,59 +383,84 @@ ui_jump_to_track_fill(gpointer treeview)
     gtk_list_store_clear(jtf_store);
 
     row = 1;
-
     playlist = playlist_get_active();
 
-    PLAYLIST_LOCK(playlist->mutex);
-
+    PLAYLIST_LOCK(playlist);
     for (playlist_glist = playlist->entries; playlist_glist;
          playlist_glist = g_list_next(playlist_glist)) {
 
         PlaylistEntry *entry = PLAYLIST_ENTRY(playlist_glist->data);
 
         if (entry->title)
-        desc_buf = g_strdup(entry->title);
-        else if (strchr(entry->filename, '/'))
-        desc_buf = str_to_utf8(strrchr(entry->filename, '/') + 1);
-        else
-        desc_buf = str_to_utf8(entry->filename);
+            desc_buf = g_strdup(entry->title);
+        else {
+            gchar *realfn = NULL;
+            realfn = g_filename_from_uri(entry->filename, NULL, NULL);
+            if (strchr(realfn ? realfn : entry->filename, '/'))
+                desc_buf = str_to_utf8(strrchr(realfn ? realfn : entry->filename, '/') + 1);
+            else
+                desc_buf = str_to_utf8(realfn ? realfn : entry->filename);
+            g_free(realfn); realfn = NULL;
+        }
 
         gtk_list_store_append(GTK_LIST_STORE(jtf_store), &iter);
         gtk_list_store_set(GTK_LIST_STORE(jtf_store), &iter,
                            0, row, 1, desc_buf, -1);
         row++;
 
-        if (desc_buf) {
-            g_free(desc_buf);
-            desc_buf = NULL;
-        }
+        g_free(desc_buf);
+        desc_buf = NULL;
     }
-
-    PLAYLIST_UNLOCK(playlist->mutex);
+    PLAYLIST_UNLOCK(playlist);
 
     /* attach liststore to treeview */
     gtk_tree_view_set_model(GTK_TREE_VIEW(treeview), GTK_TREE_MODEL(jtf_store));
     g_object_unref(jtf_store);
+    serial = playlist->serial;
     return FALSE;
 }
 
+static gboolean
+watchdog(gpointer storage)
+{
+    GtkWidget *widget;
+    Playlist *playlist = playlist_get_active();
+
+    if(serial == playlist->serial)
+        return TRUE;
+
+    widget = g_object_get_data(storage, "widget");
+    ui_jump_to_track_update(widget, storage);
+    return TRUE;
+}
+
 void
 ui_jump_to_track(void)
 {
     GtkWidget *scrollwin;
     GtkWidget *vbox, *bbox, *sep;
-    GtkWidget *jump, *queue, *cancel;
-    GtkWidget *rescan, *edit;
+    GtkWidget *toggle, *toggle2;
+    GtkWidget *jump, *queue, *close;
+    GtkWidget *rescan;
     GtkWidget *search_label, *hbox;
+    static GtkWidget *edit;
 
-    GtkWidget *treeview;
+    GtkWidget *treeview = NULL;
     GtkListStore *jtf_store;
 
     GtkCellRenderer *renderer;
     GtkTreeViewColumn *column;
 
+    gpointer storage;
+
     if (jump_to_track_win) {
         gtk_window_present(GTK_WINDOW(jump_to_track_win));
+
+        if(!cfg.remember_jtf_entry)
+            gtk_entry_set_text(GTK_ENTRY(edit), "");
+
+        gtk_widget_grab_focus(edit);
+        gtk_editable_select_region(GTK_EDITABLE(edit), 0, -1);
         return;
     }
 
@@ -504,7 +481,7 @@ ui_jump_to_track(void)
                      G_CALLBACK(gtk_widget_destroyed), &jump_to_track_win);
 
     gtk_container_border_width(GTK_CONTAINER(jump_to_track_win), 10);
-    gtk_window_set_default_size(GTK_WINDOW(jump_to_track_win), 550, 350);
+    gtk_window_set_default_size(GTK_WINDOW(jump_to_track_win), 600, 500);
 
     vbox = gtk_vbox_new(FALSE, 5);
     gtk_container_add(GTK_CONTAINER(jump_to_track_win), vbox);
@@ -538,6 +515,8 @@ ui_jump_to_track(void)
     hbox = gtk_hbox_new(FALSE, 3);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);
 
+    
+    /* filter box */
     search_label = gtk_label_new(_("Filter: "));
     gtk_label_set_markup_with_mnemonic(GTK_LABEL(search_label), _("_Filter:"));
     gtk_box_pack_start(GTK_BOX(hbox), search_label, FALSE, FALSE, 0);
@@ -556,6 +535,32 @@ ui_jump_to_track(void)
 
     gtk_box_pack_start(GTK_BOX(hbox), edit, TRUE, TRUE, 3);
 
+    /* remember text entry */
+    toggle2 = gtk_check_button_new_with_label(_("Remember"));
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(toggle2),
+                                 cfg.remember_jtf_entry ? TRUE : FALSE);
+    gtk_box_pack_start(GTK_BOX(hbox), toggle2, FALSE, FALSE, 0);
+    g_signal_connect(toggle2, "clicked",
+                     G_CALLBACK(ui_jump_to_track_toggle2_cb),
+                     toggle2);
+
+    /* clear button */
+    rescan = gtk_button_new_from_stock(GTK_STOCK_CLEAR);
+    gtk_box_pack_start(GTK_BOX(hbox), rescan, FALSE, FALSE, 0);
+
+
+    /* pack to container */
+    storage = g_object_new(G_TYPE_OBJECT, NULL);
+    g_object_set_data(storage, "widget", rescan);
+    g_object_set_data(storage, "treeview", treeview);
+    g_object_set_data(storage, "edit", edit);
+
+    g_signal_connect(rescan, "clicked",
+                     G_CALLBACK(ui_jump_to_track_update), storage);
+
+    GTK_WIDGET_SET_FLAGS(rescan, GTK_CAN_DEFAULT);
+    gtk_widget_grab_default(rescan);
+
     scrollwin = gtk_scrolled_window_new(NULL, NULL);
     gtk_container_add(GTK_CONTAINER(scrollwin), treeview);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollwin),
@@ -569,10 +574,21 @@ ui_jump_to_track(void)
 
     bbox = gtk_hbutton_box_new();
     gtk_button_box_set_layout(GTK_BUTTON_BOX(bbox), GTK_BUTTONBOX_END);
-    gtk_button_box_set_spacing(GTK_BUTTON_BOX(bbox), 5);
+    gtk_button_box_set_spacing(GTK_BUTTON_BOX(bbox), 4);
     gtk_box_pack_start(GTK_BOX(vbox), bbox, FALSE, FALSE, 0);
 
+    /* close dialog toggle */
+    toggle = gtk_check_button_new_with_label(_("Close on Jump"));
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(toggle),
+                                 cfg.close_jtf_dialog ? TRUE : FALSE);
+    gtk_box_pack_start(GTK_BOX(bbox), toggle, FALSE, FALSE, 0);
+    g_signal_connect(toggle, "clicked", 
+                     G_CALLBACK(ui_jump_to_track_toggle_cb),
+                     toggle);
+    
     queue = gtk_button_new_with_mnemonic(_("_Queue"));
+    gtk_button_set_image(GTK_BUTTON(queue),
+                     gtk_image_new_from_stock(AUD_STOCK_QUEUETOGGLE, GTK_ICON_SIZE_BUTTON));
     gtk_box_pack_start(GTK_BOX(bbox), queue, FALSE, FALSE, 0);
     GTK_WIDGET_SET_FLAGS(queue, GTK_CAN_DEFAULT);
     g_signal_connect(queue, "clicked", 
@@ -582,13 +598,6 @@ ui_jump_to_track(void)
                      G_CALLBACK(ui_jump_to_track_selection_changed_cb),
                      queue);
 
-    rescan = gtk_button_new_from_stock(GTK_STOCK_REFRESH);
-    gtk_box_pack_start(GTK_BOX(bbox), rescan, FALSE, FALSE, 0);
-    g_signal_connect(rescan, "clicked",
-                     G_CALLBACK(ui_jump_to_track_update), treeview);
-    GTK_WIDGET_SET_FLAGS(rescan, GTK_CAN_DEFAULT);
-    gtk_widget_grab_default(rescan);
-
     jump = gtk_button_new_from_stock(GTK_STOCK_JUMP_TO);
     gtk_box_pack_start(GTK_BOX(bbox), jump, FALSE, FALSE, 0);
 
@@ -599,16 +608,16 @@ ui_jump_to_track(void)
     GTK_WIDGET_SET_FLAGS(jump, GTK_CAN_DEFAULT);
     gtk_widget_grab_default(jump);
 
-    cancel = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
-    gtk_box_pack_start(GTK_BOX(bbox), cancel, FALSE, FALSE, 0);
-    g_signal_connect_swapped(cancel, "clicked",
-                             G_CALLBACK(gtk_widget_destroy),
-                             jump_to_track_win);
-    GTK_WIDGET_SET_FLAGS(cancel, GTK_CAN_DEFAULT);
+    close = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
+    gtk_box_pack_start(GTK_BOX(bbox), close, FALSE, FALSE, 0);
+    g_signal_connect_swapped(close, "clicked",
+                             G_CALLBACK(gtk_widget_hide),
+                             jump_to_track_win); // just hide --yaz
+    GTK_WIDGET_SET_FLAGS(close, GTK_CAN_DEFAULT);
 
     g_timeout_add(100, (GSourceFunc)ui_jump_to_track_fill, treeview);
+    g_timeout_add(500, (GSourceFunc)watchdog, storage);
 
     gtk_widget_show_all(jump_to_track_win);
     gtk_widget_grab_focus(edit);
 }
-
