@@ -19,7 +19,7 @@
  */
 
 #include "platform/smartinclude.h"
-#include "skin.h"
+#include "ui_skin.h"
 
 #include <gtk/gtkmain.h>
 #include <glib-object.h>
@@ -29,10 +29,8 @@
 #include <string.h>
 
 #include "main.h"
-#include "dock.h"
+#include "ui_dock.h"
 #include "ui_skinned_window.h"
-#include "ui_skinned_cursor.h"
-#include "util.h"
 #include "ui_playlist.h"
 
 static void ui_skinned_window_class_init(SkinnedWindowClass *klass);
@@ -60,53 +58,13 @@ ui_skinned_window_get_type(void)
       };
 
       window_type =
-        g_type_register_static (GTK_TYPE_WINDOW, "SkinnedWindow",
+        g_type_register_static (GTK_TYPE_WINDOW, "SkinnedWindow_",
                                 &window_info, 0);
     }
 
   return window_type;
 }
 
-static gboolean
-ui_skinned_window_configure(GtkWidget *widget,
-                            GdkEventConfigure *event)
-{
-    GtkWidgetClass *widget_class;
-    SkinnedWindow *window = SKINNED_WINDOW(widget);
-
-    widget_class = (GtkWidgetClass*) parent;
-
-    if (widget_class->configure_event != NULL)
-        widget_class->configure_event(widget, event);
-
-    if (!GTK_WIDGET_VISIBLE(widget))
-        return FALSE;
-
-    switch(window->type) {
-        case WINDOW_MAIN:
-            if (cfg.show_wm_decorations)
-                gdk_window_get_root_origin(widget->window, &cfg.player_x, &cfg.player_y);
-            else
-                gdk_window_get_deskrelative_origin(widget->window, &cfg.player_x, &cfg.player_y);
-            break;
-        case WINDOW_EQ:
-            cfg.equalizer_x = event->x;
-            cfg.equalizer_y = event->y;
-            break;
-        case WINDOW_PLAYLIST:
-            cfg.playlist_x = event->x;
-            cfg.playlist_y = event->y;
-            break;
-    }
-
-    window->x = event->x;
-    window->y = event->y;
-
-    gtk_window_set_keep_above(GTK_WINDOW(widget), cfg.always_on_top);
-
-    return FALSE;
-}
-
 static void
 ui_skinned_window_map(GtkWidget *widget)
 {
@@ -114,22 +72,17 @@ ui_skinned_window_map(GtkWidget *widget)
 
     SkinnedWindow *window = SKINNED_WINDOW(widget);
     if (window->type == WINDOW_MAIN)
-        gtk_widget_shape_combine_mask(widget, skin_get_mask(bmp_active_skin, SKIN_MASK_MAIN + cfg.player_shaded), 0, 0);
+        gtk_widget_shape_combine_mask(widget, skin_get_mask(aud_active_skin, SKIN_MASK_MAIN + cfg.player_shaded), 0, 0);
     else if (window->type == WINDOW_EQ)
-        gtk_widget_shape_combine_mask(widget, skin_get_mask(bmp_active_skin, SKIN_MASK_EQ + cfg.equalizer_shaded), 0, 0);
+        gtk_widget_shape_combine_mask(widget, skin_get_mask(aud_active_skin, SKIN_MASK_EQ + cfg.equalizer_shaded), 0, 0);
+
+    gtk_window_set_keep_above(GTK_WINDOW(widget), cfg.always_on_top);
 }
 
 static gboolean
 ui_skinned_window_motion_notify_event(GtkWidget *widget,
                                       GdkEventMotion *event)
 {
-    GtkWidgetClass *widget_class;
-
-    widget_class = (GtkWidgetClass*) parent;
-
-    if (widget_class->motion_notify_event != NULL)
-        widget_class->motion_notify_event(widget, event);
-
     if (dock_is_moving(GTK_WINDOW(widget)))
         dock_move_motion(GTK_WINDOW(widget), event);
 
@@ -148,6 +101,23 @@ static gboolean ui_skinned_window_focus_out(GtkWidget *widget, GdkEventFocus *fo
     return val;
 }
 
+static gboolean ui_skinned_window_button_press(GtkWidget *widget, GdkEventButton *event) {
+    if (event->button == 1 && event->type == GDK_BUTTON_PRESS &&
+        (cfg.easy_move || cfg.equalizer_shaded || (event->y / cfg.scale_factor) < 14)) {
+         dock_move_press(get_dock_window_list(), GTK_WINDOW(widget),
+                         event, SKINNED_WINDOW(widget)->type == WINDOW_MAIN ? TRUE : FALSE);
+    }
+
+    return TRUE;
+}
+
+static gboolean ui_skinned_window_button_release(GtkWidget *widget, GdkEventButton *event) {
+    if (dock_is_moving(GTK_WINDOW(widget)))
+       dock_move_release(GTK_WINDOW(widget));
+
+    return TRUE;
+}
+
 static gboolean ui_skinned_window_expose(GtkWidget *widget, GdkEventExpose *event) {
     SkinnedWindow *window = SKINNED_WINDOW(widget);
 
@@ -156,8 +126,8 @@ static gboolean ui_skinned_window_expose(GtkWidget *widget, GdkEventExpose *even
     gint width = 0, height = 0;
     switch (window->type) {
         case WINDOW_MAIN:
-            width = bmp_active_skin->properties.mainwin_width;
-            height = bmp_active_skin->properties.mainwin_height;
+            width = aud_active_skin->properties.mainwin_width;
+            height = aud_active_skin->properties.mainwin_height;
             break;
         case WINDOW_EQ:
             width = 275 * (cfg.scaled ? cfg.scale_factor : 1);
@@ -176,29 +146,29 @@ static gboolean ui_skinned_window_expose(GtkWidget *widget, GdkEventExpose *even
 
     switch (window->type) {
         case WINDOW_MAIN:
-            skin_draw_pixbuf(widget, bmp_active_skin, obj,SKIN_MAIN, 0, 0, 0, 0, width, height);
-            skin_draw_mainwin_titlebar(bmp_active_skin, obj, cfg.player_shaded, focus || !cfg.dim_titlebar);
+            skin_draw_pixbuf(widget, aud_active_skin, obj,SKIN_MAIN, 0, 0, 0, 0, width, height);
+            skin_draw_mainwin_titlebar(aud_active_skin, obj, cfg.player_shaded, focus || !cfg.dim_titlebar);
             break;
         case WINDOW_EQ:
-            skin_draw_pixbuf(widget, bmp_active_skin, obj, SKIN_EQMAIN, 0, 0, 0, 0, width, height);
+            skin_draw_pixbuf(widget, aud_active_skin, obj, SKIN_EQMAIN, 0, 0, 0, 0, width, height);
             if (focus || !cfg.dim_titlebar) {
                 if (!cfg.equalizer_shaded)
-                    skin_draw_pixbuf(widget, bmp_active_skin, obj, SKIN_EQMAIN, 0, 134, 0, 0, width, 14);
+                    skin_draw_pixbuf(widget, aud_active_skin, obj, SKIN_EQMAIN, 0, 134, 0, 0, width, 14);
                 else
-                    skin_draw_pixbuf(widget, bmp_active_skin, obj, SKIN_EQ_EX, 0, 0, 0, 0, width, 14);
+                    skin_draw_pixbuf(widget, aud_active_skin, obj, SKIN_EQ_EX, 0, 0, 0, 0, width, 14);
             } else {
                 if (!cfg.equalizer_shaded)
-                    skin_draw_pixbuf(widget, bmp_active_skin, obj, SKIN_EQMAIN, 0, 149, 0, 0, width, 14);
+                    skin_draw_pixbuf(widget, aud_active_skin, obj, SKIN_EQMAIN, 0, 149, 0, 0, width, 14);
                 else
-                    skin_draw_pixbuf(widget, bmp_active_skin, obj, SKIN_EQ_EX, 0, 15, 0, 0, width, 14);
+                    skin_draw_pixbuf(widget, aud_active_skin, obj, SKIN_EQ_EX, 0, 15, 0, 0, width, 14);
             }
             break;
         case WINDOW_PLAYLIST:
             focus |= !cfg.dim_titlebar;
             if (cfg.playlist_shaded) {
-                skin_draw_playlistwin_shaded(bmp_active_skin, obj, playlistwin_get_width(), focus);
+                skin_draw_playlistwin_shaded(aud_active_skin, obj, width, focus);
             } else {
-                skin_draw_playlistwin_frame(bmp_active_skin, obj, playlistwin_get_width(), cfg.playlist_height, focus);
+                skin_draw_playlistwin_frame(aud_active_skin, obj, width, cfg.playlist_height, focus);
             }
             break;
     }
@@ -220,11 +190,12 @@ ui_skinned_window_class_init(SkinnedWindowClass *klass)
 
     parent = gtk_type_class(gtk_window_get_type());
 
-    widget_class->configure_event = ui_skinned_window_configure;
     widget_class->motion_notify_event = ui_skinned_window_motion_notify_event;
     widget_class->expose_event = ui_skinned_window_expose;
     widget_class->focus_in_event = ui_skinned_window_focus_in;
     widget_class->focus_out_event = ui_skinned_window_focus_out;
+    widget_class->button_press_event = ui_skinned_window_button_press;
+    widget_class->button_release_event = ui_skinned_window_button_release;
     widget_class->map = ui_skinned_window_map;
 }
 
@@ -273,14 +244,13 @@ ui_skinned_window_new(const gchar *wmclass_name)
                           GDK_VISIBILITY_NOTIFY_MASK | GDK_EXPOSURE_MASK);
     gtk_widget_realize(GTK_WIDGET(widget));
 
-    dock_window_list = dock_window_set_decorated(dock_window_list,
-	GTK_WINDOW(widget), cfg.show_wm_decorations);
+    set_dock_window_list(dock_window_set_decorated(get_dock_window_list(),
+                                                   GTK_WINDOW(widget),
+                                                   cfg.show_wm_decorations));
     gtk_widget_set_app_paintable(GTK_WIDGET(widget), TRUE);
     gdk_window_set_back_pixmap(widget->window, NULL, FALSE);
     gtk_widget_shape_combine_mask(widget, NULL, 0, 0);
 
-    ui_skinned_cursor_set(GTK_WIDGET(widget));
-
     if (!strcmp(wmclass_name, "player"))
         SKINNED_WINDOW(widget)->type = WINDOW_MAIN;
     if (!strcmp(wmclass_name, "equalizer"))
