@@ -49,17 +49,16 @@
 #endif
 
 #include "input.h"
-#include "main.h"
 #include "playback.h"
 #include "strings.h"
-#include "ui_playlist.h"
+
 #include "libSAD.h"
 
 #ifdef USE_CHARDET
-    #include "../libguess/libguess.h"
-#ifdef HAVE_UDET
-    #include <libudet_c.h>
-#endif
+#  include "../libguess/libguess.h"
+#  ifdef HAVE_UDET
+#    include <libudet_c.h>
+#  endif
 #endif
 
 /*
@@ -755,25 +754,6 @@ glist_moveup(GList * list)
     }
 }
 
-
-void
-util_menu_position(GtkMenu * menu, gint * x, gint * y,
-                   gboolean * push_in, gpointer data)
-{
-    GtkRequisition requisition;
-    gint screen_width;
-    gint screen_height;
-    MenuPos *pos = data;
-
-    gtk_widget_size_request(GTK_WIDGET(menu), &requisition);
-
-    screen_width = gdk_screen_width();
-    screen_height = gdk_screen_height();
-
-    *x = CLAMP(pos->x - 2, 0, MAX(0, screen_width - requisition.width));
-    *y = CLAMP(pos->y - 2, 0, MAX(0, screen_height - requisition.height));
-}
-
 GdkFont *
 util_font_load(const gchar * name)
 {
@@ -910,21 +890,8 @@ make_filebrowser(const gchar *title, gboolean save)
     return dialog;
 }
 
-void ui_skinned_widget_draw(GtkWidget *widget, GdkPixbuf *obj, gint width, gint height, gboolean scale) {
-    g_return_if_fail(widget != NULL);
-    g_return_if_fail(obj != NULL);
-
-    if (scale) {
-        GdkPixbuf *image = gdk_pixbuf_scale_simple(obj, width * cfg.scale_factor, height* cfg.scale_factor, GDK_INTERP_BILINEAR);
-        gdk_draw_pixbuf(widget->window, NULL, image, 0, 0, 0, 0, width * cfg.scale_factor , height * cfg.scale_factor, GDK_RGB_DITHER_NORMAL, 0, 0);
-        g_object_unref(image);
-    } else {
-        gdk_draw_pixbuf(widget->window, NULL, obj, 0, 0, 0, 0, width, height, GDK_RGB_DITHER_NONE, 0, 0);
-    }
-}
-
 /**
- * xmms_show_message:
+ * util_info_dialog:
  * @title: The title of the message to show.
  * @text: The text of the message to show.
  * @button_text: The text of the button which will close the messagebox.
@@ -1024,10 +991,6 @@ construct_uri(gchar *string, const gchar *playlist_name) // uri, path and anythi
     /* try to translate dos path */
     convert_dos_path(filename); /* in place replacement */
 
-    /* convert backslash to slash */
-    while ((tmp = strchr(filename, '\\')) != NULL)
-        *tmp = '/';
-
     // make full path uri here
     // case 1: filename is raw full path or uri
     if (filename[0] == '/' || strstr(filename, "://")) {
@@ -1040,7 +1003,10 @@ construct_uri(gchar *string, const gchar *playlist_name) // uri, path and anythi
     // case 2: filename is not raw full path nor uri, playlist path is full path
     // make full path by replacing last part of playlist path with filename. (using g_build_filename)
     else if (playlist_name[0] == '/' || strstr(playlist_name, "://")) {
-        path = g_strdup(playlist_name);
+        path = g_filename_from_uri(playlist_name, NULL, NULL);
+        if (!path) {
+            path = g_strdup(playlist_name);
+        }
         tmp = strrchr(path, '/'); *tmp = '\0';
         tmp = g_build_filename(path, filename, NULL);
         g_free(path); g_free(filename);
@@ -1070,9 +1036,16 @@ construct_uri(gchar *string, const gchar *playlist_name) // uri, path and anythi
 gpointer
 smart_realloc(gpointer ptr, gsize *size)
 {
-    *size = (size_t)pow(2, ceil(log(*size) / log(2)) + 1);
-    if (ptr != NULL) free(ptr);
-    ptr = malloc(*size);
-    return ptr;
+    *size = (gsize)pow(2, ceil(log(*size) / log(2)) + 1);
+    return g_realloc(ptr, *size);
 }
 
+void
+make_directory(const gchar * path, mode_t mode)
+{
+    if (g_mkdir_with_parents(path, mode) == 0)
+        return;
+
+    g_printerr(_("Could not create directory (%s): %s\n"), path,
+               g_strerror(errno));
+}
