@@ -202,6 +202,7 @@ egg_desktop_file_new_from_key_file (GKeyFile    *key_file,
       if (!exec)
 	{
 	  egg_desktop_file_free (desktop_file);
+	  g_free(type);
 	  return NULL;
 	}
 
@@ -234,6 +235,7 @@ egg_desktop_file_new_from_key_file (GKeyFile    *key_file,
       if (!url)
 	{
 	  egg_desktop_file_free (desktop_file);
+	  g_free(type);
 	  return NULL;
 	}
       g_free (url);
@@ -243,6 +245,8 @@ egg_desktop_file_new_from_key_file (GKeyFile    *key_file,
   else
     desktop_file->type = EGG_DESKTOP_FILE_TYPE_UNRECOGNIZED;
 
+  g_free(type);
+
   /* Check the Icon key */
   desktop_file->icon = g_key_file_get_string (key_file,
 					      EGG_DESKTOP_FILE_GROUP,
@@ -1336,9 +1340,12 @@ egg_set_desktop_file (const char *desktop_file_path)
   egg_desktop_file = egg_desktop_file_new (desktop_file_path, &error);
   if (error)
     {
-      g_warning ("Could not load desktop file '%s': %s",
+      g_warning ("Could not load desktop file '%s': %s"
+      " - Session management may not work now.",
 		 desktop_file_path, error->message);
       g_error_free (error);
+      G_UNLOCK (egg_desktop_file);
+      return;
     }
 
   /* Set localized application name and default window icon */
